@@ -3,23 +3,23 @@
 #
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 2002-08 Chris Lawrence
-#   Copyright (C) 2008-2014 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2015 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
-##  Permission to use, copy, modify, and distribute this software and its
-##  documentation for any purpose and without fee is hereby granted,
-##  provided that the above copyright notice appears in all copies and that
-##  both that copyright notice and this permission notice appear in
-##  supporting documentation.
-##
-##  I DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
-##  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL I
-##  BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
-##  DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
-##  WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
-##  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
-##  SOFTWARE.
+#  Permission to use, copy, modify, and distribute this software and its
+#  documentation for any purpose and without fee is hereby granted,
+#  provided that the above copyright notice appears in all copies and that
+#  both that copyright notice and this permission notice appear in
+#  supporting documentation.
+#
+#  I DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
+#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL I
+#  BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
+#  DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+#  WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+#  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
+#  SOFTWARE.
 
 import sgmllib
 import commands
@@ -28,12 +28,12 @@ import utils
 from urlutils import open_url
 from reportbug.exceptions import (
     NoNetwork,
-    )
+)
 
 BUILDD_URL = 'https://buildd.debian.org/build.php?arch=%s&pkg=%s'
 
-# Check for successful in a 'td' block
 
+# Check for successful in a 'td' block
 class BuilddParser(sgmllib.SGMLParser):
     def __init__(self):
         sgmllib.SGMLParser.__init__(self)
@@ -55,7 +55,8 @@ class BuilddParser(sgmllib.SGMLParser):
     def save_end(self, mode=0):
         data = self.savedata
         self.savedata = None
-        if not mode and data is not None: data = ' '.join(data.split())
+        if not mode and data is not None:
+            data = ' '.join(data.split())
         return data
 
     def start_td(self, attrs):
@@ -64,7 +65,8 @@ class BuilddParser(sgmllib.SGMLParser):
     def end_td(self):
         data = self.save_end()
         if data and 'successful' in data.lower():
-            self.found_succeeded=True
+            self.found_succeeded = True
+
 
 def check_built(src_package, timeout, arch=None, http_proxy=None):
     """Return True if built in the past, False otherwise (even error)"""
